@@ -5,11 +5,11 @@ import re
 from typing import Any, Set, Text, Callable, List, Dict
 
 from loguru import logger
+from sentry_sdk import capture_exception
+
 from rrtv_httprunner import loader, utils, exceptions
 from rrtv_httprunner.models import VariablesMapping, FunctionsMapping
-from rrtv_httprunner.mysqls import DBHandler
-from rrtv_httprunner.utils import execute_sql,execute_cmd, get_statement_type
-from sentry_sdk import capture_exception
+from rrtv_httprunner.utils import execute_sql, execute_cmd, get_statement_type, execute_redis, execute_mongo
 
 absolute_http_url_regexp = re.compile(r"^https?://", re.I)
 
@@ -19,7 +19,7 @@ dolloar_regex_compile = re.compile(r"\$\$")
 variable_regex_compile = re.compile(r"\$\{(\w+)\}|\$(\w+)")
 # function notation, e.g. ${func1($var_1, $var_3)}
 function_regex_compile = re.compile(r"\$\{(\w+)\(([\$\w\.\-/\s=,]*)\)\}")
-suffix = ""
+suffix = []
 
 
 def parse_string_value(str_value: Text) -> Any:
@@ -38,7 +38,7 @@ def parse_string_value(str_value: Text) -> Any:
         return str_value
 
 
-def build_url(base_url, path):
+def build_url(base_url: Text, path: Text):
     """ prepend url with base_url unless it's already an absolute URL """
     if absolute_http_url_regexp.match(path):
         return path
@@ -366,9 +366,10 @@ def parse_string(
             var_name = var_match.group(1) or var_match.group(2)
             var_value = get_mapping_variable(var_name, variables_mapping)
             global suffix
-            suffix = re.findall(r'\[\'(.*?)\'\]', raw_string)
-            if suffix:
-                suffix = suffix[0]
+            suffix_re = re.findall(r'\[\'(.*?)\'\]', raw_string)
+            if suffix_re:
+                suffix = suffix_re[0]
+                raw_string = raw_string.split("[")[0]
             if f"${var_name}" == raw_string or "${" + var_name + "}" == raw_string:
                 # raw_string is a variable, $var or ${var}, return its value directly
                 return var_value
@@ -407,18 +408,53 @@ def parse_data(
         # only strip whitespaces and tabs, \n\r is left because they maybe used in changeset
         raw_data = raw_data.strip(" \t")
         var_value = parse_string(raw_data, variables_mapping, functions_mapping)
+        global suffix
+        suffix_re = re.findall(r'\[\'(.*?)\'\]', str(var_value))
+        if suffix_re:
+            suffix = suffix_re[0]
+
         if get_statement_type(var_value) == "sql":
             try:
                 value = execute_sql(variables_mapping["mysql"], var_value)
-                if value is None:  # 如果为None说明非select方法
-                    return var_value  # 直接返回原字符串
-                return execute_sql(variables_mapping["mysql"], var_value)[suffix]
-            except KeyError:  # 没有suffix后缀
-                return execute_sql(variables_mapping["mysql"], var_value)
+            except KeyError:  # 没配置数据源
+                raise exceptions.DBError("mysql datasource not configured")
+            if value is None:  # 如果为None说明非select方法
+                return var_value  # 直接返回原字符串
+            elif not suffix:  # 没有suffix后缀
+                return value
+            else:
+                try:
+                    return value[suffix]
+                except KeyError:
+                    raise exceptions.SuffixError("suffix name error")
         elif get_statement_type(var_value) == "cmd":
-            execute_cmd(var_value)
+            return execute_cmd(var_value)
+        elif get_statement_type(var_value) == "redis":
+            try:
+                return execute_redis(variables_mapping["redis"], var_value)
+            except KeyError:  # 没配置数据源
+                raise exceptions.DBError("redis datasource not configured")
+        elif get_statement_type(var_value) == "mongo":
+            try:
+                return execute_mongo(variables_mapping["mongo"], var_value)
+            except KeyError:  # 没配置数据源
+                raise exceptions.DBError("mongo datasource not configured")
         else:
-            return var_value
+
+            if isinstance(var_value, dict):
+                match_start_position = raw_data.index("]", 0)
+                parsed_string = raw_data[match_start_position + 1:]
+                if parsed_string != "" or parsed_string is not None:
+                    p=parse_string(parsed_string, variables_mapping, functions_mapping)
+                    if suffix != []:
+                        val=var_value[suffix]
+                        return parse_string_value(str(val)+ str(p))
+                    else:
+                        return parse_string_value(str(var_value) + str(p))
+                else:
+                    return var_value[suffix] if suffix != [] else var_value
+            else:
+                return var_value
 
     elif isinstance(raw_data, (list, set, tuple)):
         return [
@@ -455,8 +491,7 @@ def parse_variables_mapping(
 
             # check if reference variable itself
             if var_name in variables:
-                # e.g.
-                # variables_mapping = {"token": "abc$token"}
+                # e.g               # variables_mapping = {"token": "abc$token"}
                 # variables_mapping = {"key": ["$key", 2]}
                 raise exceptions.VariableNotFound(var_name)
 
